==> haskell-polyparse-1.12-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-polyparse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: polyparse
version: 1.12
id: polyparse-1.12-9D0YnY3UMon43vdSjbfwCd
key: polyparse-1.12-9D0YnY3UMon43vdSjbfwCd
license: LGPL
copyright: (c) 2006-2016 Malcolm Wallace
maintainer: author
homepage: http://code.haskell.org/~malcolm/polyparse/
synopsis: A variety of alternative parser combinator libraries.
description:
    A variety of alternative parser combinator libraries, including
    the original HuttonMeijer set.  The Poly sets have features like
    good error reporting, arbitrary token type, running state, lazy
    parsing, and so on.  Finally, Text.Parse is a proposed
    replacement for the standard Read class, for better
    deserialisation of Haskell values from Strings.
category: Text, Parsing
author: Malcolm Wallace <Malcolm.Wallace@me.com>
exposed: True
exposed-modules:
    Text.ParserCombinators.HuttonMeijer
    Text.ParserCombinators.HuttonMeijerWallace
    Text.ParserCombinators.Poly Text.ParserCombinators.Poly.Base
    Text.ParserCombinators.Poly.Result
    Text.ParserCombinators.Poly.Parser
    Text.ParserCombinators.Poly.Plain Text.ParserCombinators.Poly.Lazy
    Text.ParserCombinators.Poly.StateParser
    Text.ParserCombinators.Poly.State
    Text.ParserCombinators.Poly.StateLazy
    Text.ParserCombinators.Poly.Lex Text.Parse
    Text.ParserCombinators.Poly.ByteString
    Text.ParserCombinators.Poly.ByteStringChar Text.Parse.ByteString
    Text.ParserCombinators.Poly.Text
    Text.ParserCombinators.Poly.StateText
abi: c4528ea8aabc47d1276615a0e6fa4502
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/polyparse-1.12
library-dirs: /usr/lib/ghc-8.0.1/site-local/polyparse-1.12
data-dir: /usr/share/i386-linux-ghc-8.0.1/polyparse-1.12
hs-libraries: HSpolyparse-1.12-9D0YnY3UMon43vdSjbfwCd
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-polyparse/html/polyparse.haddock
haddock-html: /usr/share/doc/haskell-polyparse/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-polyparse-1.12-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-polyparse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: polyparse
version: 1.12
id: polyparse-1.12-xXhcRyjLZ1DCtbZ1LsaMo
key: polyparse-1.12-xXhcRyjLZ1DCtbZ1LsaMo
license: LGPL
copyright: (c) 2006-2016 Malcolm Wallace
maintainer: author
homepage: http://code.haskell.org/~malcolm/polyparse/
synopsis: A variety of alternative parser combinator libraries.
description:
    A variety of alternative parser combinator libraries, including
    the original HuttonMeijer set.  The Poly sets have features like
    good error reporting, arbitrary token type, running state, lazy
    parsing, and so on.  Finally, Text.Parse is a proposed
    replacement for the standard Read class, for better
    deserialisation of Haskell values from Strings.
category: Text, Parsing
author: Malcolm Wallace <Malcolm.Wallace@me.com>
exposed: True
exposed-modules:
    Text.ParserCombinators.HuttonMeijer
    Text.ParserCombinators.HuttonMeijerWallace
    Text.ParserCombinators.Poly Text.ParserCombinators.Poly.Base
    Text.ParserCombinators.Poly.Result
    Text.ParserCombinators.Poly.Parser
    Text.ParserCombinators.Poly.Plain Text.ParserCombinators.Poly.Lazy
    Text.ParserCombinators.Poly.StateParser
    Text.ParserCombinators.Poly.State
    Text.ParserCombinators.Poly.StateLazy
    Text.ParserCombinators.Poly.Lex Text.Parse
    Text.ParserCombinators.Poly.ByteString
    Text.ParserCombinators.Poly.ByteStringChar Text.Parse.ByteString
    Text.ParserCombinators.Poly.Text
    Text.ParserCombinators.Poly.StateText
abi: 9118cf45e159978da52b166a8627ae3b
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/polyparse-1.12
library-dirs: /usr/lib/ghc-8.0.1/site-local/polyparse-1.12
data-dir: /usr/share/i386-linux-ghc-8.0.1/polyparse-1.12
hs-libraries: HSpolyparse-1.12-xXhcRyjLZ1DCtbZ1LsaMo
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
haddock-interfaces: /usr/share/doc/haskell-polyparse/html/polyparse.haddock
haddock-html: /usr/share/doc/haskell-polyparse/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
